@@ -4,7 +4,7 @@ from zeep.client import Client, Settings
 
 class ClientFluig:
     def __init__(
-        self, client_soap: Optional[Client] = None, settings: Optional[Settings] = None, *, wsdl_url: str
+        self, wsdl_url: str, client_soap: Optional[Client] = None, settings: Optional[Settings] = None
     ) -> None:
         self._URL_WSDL = wsdl_url
         self._client_soap = client_soap
@@ -18,4 +18,4 @@ class ClientFluig:
 
     def get_element_in_xml(self, element: str):
         client = self.soap_intance
-        return client.get_type(element)
\ No newline at end of file
+        return client.get_type(element)
